pub(crate) enum SizingKeywordResolution {
Measure(AvailableSpace),
Exact(f32),
}Expand description
How a sizing keyword resolves to a used size
Variants
Measure(AvailableSpace)
The size is the result of measuring the item under the given available space constraint
Exact(f32)
The size resolves to an exact value without measuring the item